# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SearchAccountChildSearchAccountChild(Model):
    """SearchAccountChildSearchAccountChild.

    :param account_id: The Account identifier
    :type account_id: int
    :param account_code: The Account code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type account_code: str
    :param account_info: The Account info <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 50 characters</span>
    :type account_info: str
    :param active: Indicates whether the Account is active or inactive
    :type active: bool
    :param account_type: The type of the Account. Examples include billing,
     chargeback and invoicing
    :type account_type: ~energycap.sdk.models.AccountTypeChild
    :param vendor: The Account's vendor
    :type vendor: ~energycap.sdk.models.VendorChild
    :param address: The address of the Account
    :type address: ~energycap.sdk.models.AddressChild
    :param parent_path: The collection of cost centers representing the path
     to its parent
    :type parent_path: list[~energycap.sdk.models.CostCenterChild]
    :param has_calculated_meter: Indicates whether the Account has a child
     calculated meter
    :type has_calculated_meter: bool
    :param has_split_parent_meter: Indicates whether the Account is a
     recipient of a split
    :type has_split_parent_meter: bool
    :param has_split_child_meter: Indicates whether the Account has a child
     split meter
    :type has_split_child_meter: bool
    """

    _validation = {
        'account_code': {'required': True, 'max_length': 32, 'min_length': 0},
        'account_info': {'required': True, 'max_length': 50, 'min_length': 0},
    }

    _attribute_map = {
        'account_id': {'key': 'accountId', 'type': 'int'},
        'account_code': {'key': 'accountCode', 'type': 'str'},
        'account_info': {'key': 'accountInfo', 'type': 'str'},
        'active': {'key': 'active', 'type': 'bool'},
        'account_type': {'key': 'accountType', 'type': 'AccountTypeChild'},
        'vendor': {'key': 'vendor', 'type': 'VendorChild'},
        'address': {'key': 'address', 'type': 'AddressChild'},
        'parent_path': {'key': 'parentPath', 'type': '[CostCenterChild]'},
        'has_calculated_meter': {'key': 'hasCalculatedMeter', 'type': 'bool'},
        'has_split_parent_meter': {'key': 'hasSplitParentMeter', 'type': 'bool'},
        'has_split_child_meter': {'key': 'hasSplitChildMeter', 'type': 'bool'},
    }

    def __init__(self, account_code, account_info, account_id=None, active=None, account_type=None, vendor=None, address=None, parent_path=None, has_calculated_meter=None, has_split_parent_meter=None, has_split_child_meter=None):
        super(SearchAccountChildSearchAccountChild, self).__init__()
        self.account_id = account_id
        self.account_code = account_code
        self.account_info = account_info
        self.active = active
        self.account_type = account_type
        self.vendor = vendor
        self.address = address
        self.parent_path = parent_path
        self.has_calculated_meter = has_calculated_meter
        self.has_split_parent_meter = has_split_parent_meter
        self.has_split_child_meter = has_split_child_meter



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BaselineLogEntry(Model):
    """NOTE: This child object is subject to change depending on what we want to
    log.

    :param meter_id: ID of the meter
    :type meter_id: int
    :param status: Status of the meter's baseline processing
    :type status: str
    :param message: Error or warning message from baseline processing
     Will be blank if no errors or warnings
    :type message: str
    """

    _attribute_map = {
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'status': {'key': 'status', 'type': 'str'},
        'message': {'key': 'message', 'type': 'str'},
    }

    def __init__(self, meter_id=None, status=None, message=None):
        super(BaselineLogEntry, self).__init__()
        self.meter_id = meter_id
        self.status = status
        self.message = message



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BaselineLog(Model):
    """BaselineLog.

    :param status: The status of baseline processing
    :type status: str
    :param success_count: Number of meters successfully processed
    :type success_count: int
    :param warning_count: Number of meters processed with warnings
    :type warning_count: int
    :param error_count: Number of meters processed with errors
    :type error_count: int
    :param number_of_meters: Number of meters to process
    :type number_of_meters: int
    :param baseline_log_entries: Log entries for the baseline processor
     There will be one per meter processed
    :type baseline_log_entries: list[~energycap.sdk.models.BaselineLogEntry]
    """

    _attribute_map = {
        'status': {'key': 'status', 'type': 'str'},
        'success_count': {'key': 'successCount', 'type': 'int'},
        'warning_count': {'key': 'warningCount', 'type': 'int'},
        'error_count': {'key': 'errorCount', 'type': 'int'},
        'number_of_meters': {'key': 'numberOfMeters', 'type': 'int'},
        'baseline_log_entries': {'key': 'baselineLogEntries', 'type': '[BaselineLogEntry]'},
    }

    def __init__(self, status=None, success_count=None, warning_count=None, error_count=None, number_of_meters=None, baseline_log_entries=None):
        super(BaselineLog, self).__init__()
        self.status = status
        self.success_count = success_count
        self.warning_count = warning_count
        self.error_count = error_count
        self.number_of_meters = number_of_meters
        self.baseline_log_entries = baseline_log_entries



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SavingsLogEntry(Model):
    """NOTE: This child object is subject to change depending on what we want to
    log.

    :param meter_id: ID of the meter
    :type meter_id: int
    :param bill_id: ID of the bill
    :type bill_id: int
    :param weather_station_code: Weather station code of the station assigned
     to the meter's parent building
    :type weather_station_code: str
    :param weather_error: Indicates if there was a cost avoidance processing
     problem related to weather
    :type weather_error: bool
    :param auc_error: Indicates if there was a cost avoidance processing
     problem related to average unit cost range configured for this meter's
     commodity
    :type auc_error: bool
    """

    _attribute_map = {
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'bill_id': {'key': 'billId', 'type': 'int'},
        'weather_station_code': {'key': 'weatherStationCode', 'type': 'str'},
        'weather_error': {'key': 'weatherError', 'type': 'bool'},
        'auc_error': {'key': 'aucError', 'type': 'bool'},
    }

    def __init__(self, meter_id=None, bill_id=None, weather_station_code=None, weather_error=None, auc_error=None):
        super(SavingsLogEntry, self).__init__()
        self.meter_id = meter_id
        self.bill_id = bill_id
        self.weather_station_code = weather_station_code
        self.weather_error = weather_error
        self.auc_error = auc_error



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BaselineProcessorResponse(Model):
    """BaselineProcessorResponse.

    :param include_in_cap: Indicates if the meter will be included in savings
     calculations
    :type include_in_cap: bool
    :param adjust_area: Indicates if floor area adjustments should be made
    :type adjust_area: bool
    :param adjusted_cost_type: The type of cost adjustment to perform.
     Possible values include 1 (current average unit cost) and 5 (net cost
     difference)
    :type adjusted_cost_type: ~energycap.sdk.models.AdjustedCostTypeResponse
    :param adjust_winter: Indicates if winter weather adjustments should be
     made
    :type adjust_winter: bool
    :param adjust_summer: Indicates if summer weather adjustments should be
     made
    :type adjust_summer: bool
    :param baseline_months: The number of months in the baseline.
     Setting this to anything other than 12 will turn off weather adjustments
     irregardless of the settings in adjustWinter and adjustSummer
    :type baseline_months: int
    :param baseline_start_date: The baseline's start date
    :type baseline_start_date: datetime
    :param savings_start_date: The savings period's start date
    :type savings_start_date: datetime
    :param use_extended_weather: Indicates if extended weather should be used.
     Extended weather uses additional months prior to the baseline start date
     to
     determine weather sensitivity.
    :type use_extended_weather: bool
    :param extended_weather_start_date: The start date of the extended
     weather. This should be 1, 2 or 3 years prior to the baseline start date.
     Extended weather uses additional months prior to the baseline start date
     to
     determine weather sensitivity.
    :type extended_weather_start_date: datetime
    :param cooling_temp: The cooling balance point
    :type cooling_temp: int
    :param cooling_intercept: The cooling intercept
    :type cooling_intercept: float
    :param cooling_max_degree_days: The cooling max degree days
    :type cooling_max_degree_days: float
    :param cooling_max_use: The cooling max use
    :type cooling_max_use: float
    :param cooling_r2: The cooling R2
    :type cooling_r2: float
    :param cooling_min_r2: The cooling minimum R2
    :type cooling_min_r2: float
    :param cooling_calculated_r2: The cooling calculated R2
    :type cooling_calculated_r2: float
    :param cooling_slope: The cooling slope
    :type cooling_slope: float
    :param cooling_std_dev: The cooling standard deviation
    :type cooling_std_dev: float
    :param heating_temp: The heating balance point
    :type heating_temp: int
    :param heating_intercept: The heating intecept
    :type heating_intercept: float
    :param heating_max_degree_days: The heating maximum degree days
    :type heating_max_degree_days: float
    :param heating_max_use: The heating maximum use
    :type heating_max_use: float
    :param heating_r2: The heating R2
    :type heating_r2: float
    :param heating_min_r2: The heating minimum R2
    :type heating_min_r2: float
    :param heating_calculated_r2: The heating calculated R2
    :type heating_calculated_r2: float
    :param heating_slope: The heating slope
    :type heating_slope: float
    :param heating_std_dev: The heating standard deviation
    :type heating_std_dev: float
    :param baseline_bills: Indicates if each bill in the baseline should be
     included in the baseline regression
    :type baseline_bills:
     list[~energycap.sdk.models.BaselineProcessorResponseBaselineBill]
    """

    _attribute_map = {
        'include_in_cap': {'key': 'includeInCAP', 'type': 'bool'},
        'adjust_area': {'key': 'adjustArea', 'type': 'bool'},
        'adjusted_cost_type': {'key': 'adjustedCostType', 'type': 'AdjustedCostTypeResponse'},
        'adjust_winter': {'key': 'adjustWinter', 'type': 'bool'},
        'adjust_summer': {'key': 'adjustSummer', 'type': 'bool'},
        'baseline_months': {'key': 'baselineMonths', 'type': 'int'},
        'baseline_start_date': {'key': 'baselineStartDate', 'type': 'iso-8601'},
        'savings_start_date': {'key': 'savingsStartDate', 'type': 'iso-8601'},
        'use_extended_weather': {'key': 'useExtendedWeather', 'type': 'bool'},
        'extended_weather_start_date': {'key': 'extendedWeatherStartDate', 'type': 'iso-8601'},
        'cooling_temp': {'key': 'coolingTemp', 'type': 'int'},
        'cooling_intercept': {'key': 'coolingIntercept', 'type': 'float'},
        'cooling_max_degree_days': {'key': 'coolingMaxDegreeDays', 'type': 'float'},
        'cooling_max_use': {'key': 'coolingMaxUse', 'type': 'float'},
        'cooling_r2': {'key': 'coolingR2', 'type': 'float'},
        'cooling_min_r2': {'key': 'coolingMinR2', 'type': 'float'},
        'cooling_calculated_r2': {'key': 'coolingCalculatedR2', 'type': 'float'},
        'cooling_slope': {'key': 'coolingSlope', 'type': 'float'},
        'cooling_std_dev': {'key': 'coolingStdDev', 'type': 'float'},
        'heating_temp': {'key': 'heatingTemp', 'type': 'int'},
        'heating_intercept': {'key': 'heatingIntercept', 'type': 'float'},
        'heating_max_degree_days': {'key': 'heatingMaxDegreeDays', 'type': 'float'},
        'heating_max_use': {'key': 'heatingMaxUse', 'type': 'float'},
        'heating_r2': {'key': 'heatingR2', 'type': 'float'},
        'heating_min_r2': {'key': 'heatingMinR2', 'type': 'float'},
        'heating_calculated_r2': {'key': 'heatingCalculatedR2', 'type': 'float'},
        'heating_slope': {'key': 'heatingSlope', 'type': 'float'},
        'heating_std_dev': {'key': 'heatingStdDev', 'type': 'float'},
        'baseline_bills': {'key': 'baselineBills', 'type': '[BaselineProcessorResponseBaselineBill]'},
    }

    def __init__(self, include_in_cap=None, adjust_area=None, adjusted_cost_type=None, adjust_winter=None, adjust_summer=None, baseline_months=None, baseline_start_date=None, savings_start_date=None, use_extended_weather=None, extended_weather_start_date=None, cooling_temp=None, cooling_intercept=None, cooling_max_degree_days=None, cooling_max_use=None, cooling_r2=None, cooling_min_r2=None, cooling_calculated_r2=None, cooling_slope=None, cooling_std_dev=None, heating_temp=None, heating_intercept=None, heating_max_degree_days=None, heating_max_use=None, heating_r2=None, heating_min_r2=None, heating_calculated_r2=None, heating_slope=None, heating_std_dev=None, baseline_bills=None):
        super(BaselineProcessorResponse, self).__init__()
        self.include_in_cap = include_in_cap
        self.adjust_area = adjust_area
        self.adjusted_cost_type = adjusted_cost_type
        self.adjust_winter = adjust_winter
        self.adjust_summer = adjust_summer
        self.baseline_months = baseline_months
        self.baseline_start_date = baseline_start_date
        self.savings_start_date = savings_start_date
        self.use_extended_weather = use_extended_weather
        self.extended_weather_start_date = extended_weather_start_date
        self.cooling_temp = cooling_temp
        self.cooling_intercept = cooling_intercept
        self.cooling_max_degree_days = cooling_max_degree_days
        self.cooling_max_use = cooling_max_use
        self.cooling_r2 = cooling_r2
        self.cooling_min_r2 = cooling_min_r2
        self.cooling_calculated_r2 = cooling_calculated_r2
        self.cooling_slope = cooling_slope
        self.cooling_std_dev = cooling_std_dev
        self.heating_temp = heating_temp
        self.heating_intercept = heating_intercept
        self.heating_max_degree_days = heating_max_degree_days
        self.heating_max_use = heating_max_use
        self.heating_r2 = heating_r2
        self.heating_min_r2 = heating_min_r2
        self.heating_calculated_r2 = heating_calculated_r2
        self.heating_slope = heating_slope
        self.heating_std_dev = heating_std_dev
        self.baseline_bills = baseline_bills



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CostCenterCreate(Model):
    """CostCenterCreate.

    :param cost_center_code: The cost center code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type cost_center_code: str
    :param cost_center_info: The cost center info <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type cost_center_info: str
    :param parent_cost_center_id: The identifier for the parent of the cost
     center. The parent is the cost center directly above the current cost
     center on the Accounts tree <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Topmost (CostCenter)</span>
    :type parent_cost_center_id: int
    """

    _validation = {
        'cost_center_code': {'required': True, 'max_length': 32, 'min_length': 0},
        'cost_center_info': {'required': True, 'max_length': 32, 'min_length': 0},
        'parent_cost_center_id': {'required': True},
    }

    _attribute_map = {
        'cost_center_code': {'key': 'costCenterCode', 'type': 'str'},
        'cost_center_info': {'key': 'costCenterInfo', 'type': 'str'},
        'parent_cost_center_id': {'key': 'parentCostCenterId', 'type': 'int'},
    }

    def __init__(self, cost_center_code, cost_center_info, parent_cost_center_id):
        super(CostCenterCreate, self).__init__()
        self.cost_center_code = cost_center_code
        self.cost_center_info = cost_center_info
        self.parent_cost_center_id = parent_cost_center_id
